( cd usr/lib ; rm -rf libfftw3l_threads.so.3 )
( cd usr/lib ; ln -sf libfftw3l_threads.so.3.2.2 libfftw3l_threads.so.3 )
( cd usr/lib ; rm -rf libfftw3l_threads.so )
( cd usr/lib ; ln -sf libfftw3l_threads.so.3.2.2 libfftw3l_threads.so )
( cd usr/lib ; rm -rf libfftw3l.so.3 )
( cd usr/lib ; ln -sf libfftw3l.so.3.2.2 libfftw3l.so.3 )
( cd usr/lib ; rm -rf libfftw3l.so )
( cd usr/lib ; ln -sf libfftw3l.so.3.2.2 libfftw3l.so )
